Configuration
=============

Linter rules can easily be ignored with the `-i` or `--ignore` flag.

For example:

.. code:: bash

   djlint src -i "W013,W014"


Help needed!
------------

Ideally we'd also like to be able to ignore rules through pyproject.toml/tox.ini/setup.cfg.
